combination_forecast_inside: This function is call to be inside fforms_combination
Description
Given weights and time series in a two seperate vectors calculate combination forecast
Usage
combination_forecast_inside(x, y, h)
Arguments
x
weights and names of models (output based on fforms.ensemble)
Value
list of combination forecasts corresponds to point, lower and upper